@@ -1,8 +1,9 @@
-//#![deny(clippy::all)]
-//#![deny(clippy::pedantic)]
+#![deny(clippy::all)]
+#![deny(clippy::pedantic)]
 #![deny(clippy::cargo)]
 #![allow(clippy::multiple_crate_versions)] // This should be enforced by cargo-deny
-//#![deny(missing_docs)]
+#![deny(missing_docs)]
+#![allow(clippy::missing_errors_doc)]
 #![forbid(unsafe_code)]
 
 //! This crate is the primary Rust API for interacting with Rigetti products. Specifically, this
@@ -10,13 +11,12 @@
 //! using [`Executable`].
 
 pub use executable::{Error, Executable, JobHandle, Service};
-pub use execution_data::ExecutionData;
+pub use execution_data::Qvm;
 pub use register_data::RegisterData;
 
 pub mod api;
-pub mod configuration;
 mod executable;
 mod execution_data;
-mod qpu;
+pub mod qpu;
 mod qvm;
 mod register_data;
